@@ -1,7 +1,9 @@
 package WordList;
 
-our $DATE = '2018-04-03'; # DATE
-our $VERSION = '0.4.1'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-01'; # DATE
+our $DIST = 'WordList'; # DIST
+our $VERSION = '0.5.0'; # VERSION
 
 use strict 'subs', 'vars';
 
@@ -109,7 +111,7 @@ WordList - Word lists
 
 =head1 VERSION
 
-This document describes version 0.4.1 of WordList (from Perl distribution WordList), released on 2018-04-03.
+This document describes version 0.5.0 of WordList (from Perl distribution WordList), released on 2020-05-01.
 
 =head1 SYNOPSIS
 
@@ -222,8 +224,8 @@ Usage:
 Check whether C<$word> is in the list.
 
 Algorithm in this implementation is linear scan (O(n)). Check out
-L<WordList::Role::BinarySearch> for an O(log n) implementation, or
-L<WordList::Role::Bloom> for O(1) implementation.
+L<WordListRole::BinarySearch> for an O(log n) implementation, or
+L<WordListRole::Bloom> for O(1) implementation.
 
 =head2 all_words
 
@@ -253,9 +255,11 @@ feature.
 
 =head1 SEE ALSO
 
-C<WordList::Role::*> modules.
+C<WordListRole::*> modules.
 
-Other C<WordList::*> modules.
+C<WordListMod::*> modules.
+
+C<WordList::*> modules.
 
 =head1 AUTHOR
 
@@ -263,7 +267,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
